@@ -1,9 +1,18 @@
-Convert_Simulated_Networks_To_Observed_Scale <- function(
+#' Transforms simulated networks to observed scale. In general, do not use this function.
+#'
+#' @param GERGM_Object A GERGM object returned by the `gergm()` function. In
+#' general, this function should not be used except in the case where you are
+#' working with a GERGM object where the `@MCMC_output$Networks` field is still
+#' on the [0,1] unconstrained space, and you wish to transform it to the
+#' observed scale.
+#' @return A GERGM Object
+#' @export
+convert_simulated_networks_to_observed_scale <- function(
   GERGM_Object){
   # determine the number of MCMC samples
   samples <- dim(GERGM_Object@MCMC_output$Networks)[3]
   num.nodes <- GERGM_Object@num_nodes
-  triples = t(combn(1:num.nodes, 3))
+  triples = GERGM_Object@statistic_auxiliary_data$triples
   stats <- rep(1,length(GERGM_Object@stats_to_use))
   transformation_type <- GERGM_Object@transformation_type
 
