@@ -4,6 +4,7 @@ Create_GERGM_Object_From_Formula <- function(object,
                                              possible_structural_terms,
                                              possible_covariate_terms,
                                              possible_network_terms,
+                                             using_distribution_estimator,
                                              raw_network,
                                              together = 1,
                                              transform.data = NULL,
@@ -20,6 +21,7 @@ Create_GERGM_Object_From_Formula <- function(object,
                                possible_structural_terms,
                                possible_covariate_terms,
                                possible_network_terms,
+                               using_distribution_estimator = using_distribution_estimator,
                                raw_network = raw_network,
                                theta = theta.coef,
                                terms_to_parse = "structural",
