@@ -31,6 +31,7 @@ single_gergm_specification <- function(i,
                                        stop_for_degeneracy,
                                        target_accept_rate,
                                        theta_grid_optimization_list,
+                                       beta_correlation_model,
                                        weighted_MPLE,
                                        fine_grained_pv_optimization,
                                        parallel,
@@ -433,6 +434,7 @@ single_gergm_specification <- function(i,
     stop_for_degeneracy = stop_for_degeneracy,
     target_accept_rate = target_accept_rate,
     theta_grid_optimization_list = theta_grid_optimization_list,
+    beta_correlation_model = beta_correlation_model,
     weighted_MPLE = weighted_MPLE,
     fine_grained_pv_optimization = fine_grained_pv_optimization,
     parallel = parallel,
